(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/common'), require('@angular/core'), require('@prismicio/helpers'), require('@angular/platform-browser'), require('@angular/router'), require('@prismicio/client'), require('rxjs'), require('rxjs/operators')) :
    typeof define === 'function' && define.amd ? define('@ngx-prismic/client', ['exports', '@angular/common', '@angular/core', '@prismicio/helpers', '@angular/platform-browser', '@angular/router', '@prismicio/client', 'rxjs', 'rxjs/operators'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory((global['ngx-prismic'] = global['ngx-prismic'] || {}, global['ngx-prismic'].client = {}), global.ng.common, global.ng.core, global.helpers, global.ng.platformBrowser, global.ng.router, global.client, global.rxjs, global.rxjs.operators));
}(this, (function (exports, common, i0, helpers, platformBrowser, i1, client, rxjs, operators) { 'use strict';

    /**
     * This pipe is used to render an array of Prismic Paragraphs
     * to HTML.
     *
     * @example
     * <!-- text is an array of paragraphs -->
     * <ng-container [innerHTML]="doc.data.text | renderHtml"></ng-container>
     */
    var RenderHtmlPipe = /** @class */ (function () {
        function RenderHtmlPipe() {
        }
        /**
         * Takes Paragraphs and renders them to HTML.
         * It is possible to use a custom serializer function to change rendering
         * of certain elements, for example to add classes to standard tags.
         *
         * @param value paragraph definition to render
         * @param htmlSerializer optional HtmlResolver which modifies the rendering of certain elements
         */
        RenderHtmlPipe.prototype.transform = function (value, htmlSerializer) {
            if (!(Array.isArray(value) && value.length > 0)) {
                return '';
            }
            return helpers.asHTML(value, undefined, htmlSerializer);
        };
        return RenderHtmlPipe;
    }());
    RenderHtmlPipe.decorators = [
        { type: i0.Pipe, args: [{
                    name: 'renderHtml'
                },] }
    ];

    /**
     * This pipe is used to render a Prismic Image to HTML.
     *
     * @example
     * <ng-container [innerHTML]="doc.image | renderImage : 'my extra classes'"></ng-container>
     */
    var RenderImagePipe = /** @class */ (function () {
        function RenderImagePipe() {
        }
        /**
         * Renders an image object returned from Prismic to HTML.
         *
         * @param image image object returned from Prismic
         * @param imgTitle optional title for the image
         * @param imgClasses optional classes for the image
         * @param caption optional <figcaption>
         */
        RenderImagePipe.prototype.transform = function (image, imgTitle, imgClasses, caption) {
            var classes = imgClasses ? " class=\"" + imgClasses + "\"" : '';
            var alt = image.alt ? " alt=\"" + image.alt + "\"" : '';
            var title = imgTitle ? " title=\"" + imgTitle + "\"" : '';
            var src = " src=\"" + image.url + "\"";
            var img = "<img" + classes + alt + title + src + ">";
            if (caption) {
                return "<figure>" + img + "<figcaption>" + helpers.asHTML(caption) + "</figcaption></figure>";
            }
            return img;
        };
        return RenderImagePipe;
    }());
    RenderImagePipe.decorators = [
        { type: i0.Pipe, args: [{
                    name: 'renderImage'
                },] }
    ];

    /**
     * A Pipe to easily sanitize different types of content.
     *
     * Credit goes to Swarna:
     * https://medium.com/@swarnakishore/angular-safe-pipe-implementation-to-bypass-domsanitizer-stripping-out-content-c1bf0f1cc36b
     */
    var SafePipe = /** @class */ (function () {
        function SafePipe(sanitizer) {
            this.sanitizer = sanitizer;
        }
        SafePipe.prototype.transform = function (value, type) {
            switch (type) {
                case 'html': return this.sanitizer.bypassSecurityTrustHtml(value);
                case 'style': return this.sanitizer.bypassSecurityTrustStyle(value);
                case 'script': return this.sanitizer.bypassSecurityTrustScript(value);
                case 'url': return this.sanitizer.bypassSecurityTrustUrl(value);
                case 'resourceUrl': return this.sanitizer.bypassSecurityTrustResourceUrl(value);
                default: throw new Error("Invalid safe type specified: " + type);
            }
        };
        return SafePipe;
    }());
    SafePipe.decorators = [
        { type: i0.Pipe, args: [{
                    name: 'safe'
                },] }
    ];
    SafePipe.ctorParameters = function () { return [
        { type: platformBrowser.DomSanitizer }
    ]; };

    var PrismicClientModule = /** @class */ (function () {
        function PrismicClientModule() {
        }
        return PrismicClientModule;
    }());
    PrismicClientModule.decorators = [
        { type: i0.NgModule, args: [{
                    declarations: [
                        RenderHtmlPipe,
                        RenderImagePipe,
                        SafePipe
                    ],
                    imports: [
                        common.CommonModule
                    ],
                    exports: [
                        RenderHtmlPipe,
                        RenderImagePipe,
                        SafePipe
                    ]
                },] }
    ];

    /**
     * Name of your prismic repository.
     */
    var REPOSITORY_NAME = new i0.InjectionToken('REPOSITORY_NAME');
    /**
     * Injection token to provide a link resolver function.
     *
     * This could be done based on doc type and uid.
     */
    var LINK_RESOLVER = new i0.InjectionToken('LINK_RESOLVER');
    /**
     * Injection token to provide a custom fallback route for link resolving.
     * Default is `/`.
     */
    var LINK_RESOLVER_DEFAULT_ROUTE = new i0.InjectionToken('LINK_RESOLVER_DEFAULT_ROUTE');
    /**
     * Injection token to provide the URL for the link resolver.
     *
     * This value must match the setting in your Prismic Repo.
     */
    var LINK_RESOLVER_URL = new i0.InjectionToken('LINK_RESOLVER_URL');
    /**
     * A Guard to easily enable redirects for Prismic Previews.
     * You must provide `LINK_RESOLVER` and `LINK_RESOLVER_URL`.
     *
     * When a preview-token is present, this guard automatically
     * redirects based on the provided `LINK_RESOLVER`.
     *
     * If no token is present, the guard does nothing.
     *
     * Compiler-Flags:
     * - @dynamic (Allow lambda functions)
     */
    var PreviewGuard = /** @class */ (function () {
        function PreviewGuard(router, repoName, linkResolver, linkResolverUrl, defaultRoute) {
            if (defaultRoute === void 0) { defaultRoute = '/'; }
            this.router = router;
            this.repoName = repoName;
            this.linkResolver = linkResolver;
            this.linkResolverUrl = linkResolverUrl;
            this.defaultRoute = defaultRoute;
            /**
             * Prismic supplies the preview token in a query param named `token`.
             */
            this.QUERY_PARAM_KEY = 'token';
            var endpoint = client.getEndpoint(this.repoName);
            this.client = client.createClient(endpoint);
        }
        PreviewGuard.prototype.canActivateChild = function (next, state) {
            var _this = this;
            if (state.url.startsWith(this.linkResolverUrl)) {
                var params = next.queryParamMap;
                if (!params.has(this.QUERY_PARAM_KEY)) {
                    return this.router.parseUrl(this.defaultRoute);
                }
                var previewToken = params.get(this.QUERY_PARAM_KEY);
                var resolvedUrl = rxjs.from(this.client.resolvePreviewURL({
                    previewToken: previewToken,
                    linkResolver: this.linkResolver,
                    defaultURL: this.defaultRoute
                }));
                return resolvedUrl.pipe(operators.map(function (url) { return _this.router.parseUrl(url); }));
            }
            return true;
        };
        return PreviewGuard;
    }());
    PreviewGuard.ɵprov = i0.ɵɵdefineInjectable({ factory: function PreviewGuard_Factory() { return new PreviewGuard(i0.ɵɵinject(i1.Router), i0.ɵɵinject(REPOSITORY_NAME), i0.ɵɵinject(LINK_RESOLVER), i0.ɵɵinject(LINK_RESOLVER_URL), i0.ɵɵinject(LINK_RESOLVER_DEFAULT_ROUTE, 8)); }, token: PreviewGuard, providedIn: "root" });
    PreviewGuard.decorators = [
        { type: i0.Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    PreviewGuard.ctorParameters = function () { return [
        { type: i1.Router },
        { type: String, decorators: [{ type: i0.Inject, args: [REPOSITORY_NAME,] }] },
        { type: undefined, decorators: [{ type: i0.Inject, args: [LINK_RESOLVER,] }] },
        { type: String, decorators: [{ type: i0.Inject, args: [LINK_RESOLVER_URL,] }] },
        { type: undefined, decorators: [{ type: i0.Inject, args: [LINK_RESOLVER_DEFAULT_ROUTE,] }, { type: i0.Optional }] }
    ]; };

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */
    /* global Reflect, Promise */
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b)
                if (Object.prototype.hasOwnProperty.call(b, p))
                    d[p] = b[p]; };
        return extendStatics(d, b);
    };
    function __extends(d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    }
    var __assign = function () {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s)
                    if (Object.prototype.hasOwnProperty.call(s, p))
                        t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };
    function __rest(s, e) {
        var t = {};
        for (var p in s)
            if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }
    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function")
            r = Reflect.decorate(decorators, target, key, desc);
        else
            for (var i = decorators.length - 1; i >= 0; i--)
                if (d = decorators[i])
                    r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }
    function __param(paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); };
    }
    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function")
            return Reflect.metadata(metadataKey, metadataValue);
    }
    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try {
                step(generator.next(value));
            }
            catch (e) {
                reject(e);
            } }
            function rejected(value) { try {
                step(generator["throw"](value));
            }
            catch (e) {
                reject(e);
            } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }
    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function () { if (t[0] & 1)
                throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function () { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f)
                throw new TypeError("Generator is already executing.");
            while (_)
                try {
                    if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done)
                        return t;
                    if (y = 0, t)
                        op = [op[0] & 2, t.value];
                    switch (op[0]) {
                        case 0:
                        case 1:
                            t = op;
                            break;
                        case 4:
                            _.label++;
                            return { value: op[1], done: false };
                        case 5:
                            _.label++;
                            y = op[1];
                            op = [0];
                            continue;
                        case 7:
                            op = _.ops.pop();
                            _.trys.pop();
                            continue;
                        default:
                            if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) {
                                _ = 0;
                                continue;
                            }
                            if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) {
                                _.label = op[1];
                                break;
                            }
                            if (op[0] === 6 && _.label < t[1]) {
                                _.label = t[1];
                                t = op;
                                break;
                            }
                            if (t && _.label < t[2]) {
                                _.label = t[2];
                                _.ops.push(op);
                                break;
                            }
                            if (t[2])
                                _.ops.pop();
                            _.trys.pop();
                            continue;
                    }
                    op = body.call(thisArg, _);
                }
                catch (e) {
                    op = [6, e];
                    y = 0;
                }
                finally {
                    f = t = 0;
                }
            if (op[0] & 5)
                throw op[1];
            return { value: op[0] ? op[1] : void 0, done: true };
        }
    }
    var __createBinding = Object.create ? (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        Object.defineProperty(o, k2, { enumerable: true, get: function () { return m[k]; } });
    }) : (function (o, m, k, k2) {
        if (k2 === undefined)
            k2 = k;
        o[k2] = m[k];
    });
    function __exportStar(m, o) {
        for (var p in m)
            if (p !== "default" && !Object.prototype.hasOwnProperty.call(o, p))
                __createBinding(o, m, p);
    }
    function __values(o) {
        var s = typeof Symbol === "function" && Symbol.iterator, m = s && o[s], i = 0;
        if (m)
            return m.call(o);
        if (o && typeof o.length === "number")
            return {
                next: function () {
                    if (o && i >= o.length)
                        o = void 0;
                    return { value: o && o[i++], done: !o };
                }
            };
        throw new TypeError(s ? "Object is not iterable." : "Symbol.iterator is not defined.");
    }
    function __read(o, n) {
        var m = typeof Symbol === "function" && o[Symbol.iterator];
        if (!m)
            return o;
        var i = m.call(o), r, ar = [], e;
        try {
            while ((n === void 0 || n-- > 0) && !(r = i.next()).done)
                ar.push(r.value);
        }
        catch (error) {
            e = { error: error };
        }
        finally {
            try {
                if (r && !r.done && (m = i["return"]))
                    m.call(i);
            }
            finally {
                if (e)
                    throw e.error;
            }
        }
        return ar;
    }
    /** @deprecated */
    function __spread() {
        for (var ar = [], i = 0; i < arguments.length; i++)
            ar = ar.concat(__read(arguments[i]));
        return ar;
    }
    /** @deprecated */
    function __spreadArrays() {
        for (var s = 0, i = 0, il = arguments.length; i < il; i++)
            s += arguments[i].length;
        for (var r = Array(s), k = 0, i = 0; i < il; i++)
            for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
                r[k] = a[j];
        return r;
    }
    function __spreadArray(to, from, pack) {
        if (pack || arguments.length === 2)
            for (var i = 0, l = from.length, ar; i < l; i++) {
                if (ar || !(i in from)) {
                    if (!ar)
                        ar = Array.prototype.slice.call(from, 0, i);
                    ar[i] = from[i];
                }
            }
        return to.concat(ar || from);
    }
    function __await(v) {
        return this instanceof __await ? (this.v = v, this) : new __await(v);
    }
    function __asyncGenerator(thisArg, _arguments, generator) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var g = generator.apply(thisArg, _arguments || []), i, q = [];
        return i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i;
        function verb(n) { if (g[n])
            i[n] = function (v) { return new Promise(function (a, b) { q.push([n, v, a, b]) > 1 || resume(n, v); }); }; }
        function resume(n, v) { try {
            step(g[n](v));
        }
        catch (e) {
            settle(q[0][3], e);
        } }
        function step(r) { r.value instanceof __await ? Promise.resolve(r.value.v).then(fulfill, reject) : settle(q[0][2], r); }
        function fulfill(value) { resume("next", value); }
        function reject(value) { resume("throw", value); }
        function settle(f, v) { if (f(v), q.shift(), q.length)
            resume(q[0][0], q[0][1]); }
    }
    function __asyncDelegator(o) {
        var i, p;
        return i = {}, verb("next"), verb("throw", function (e) { throw e; }), verb("return"), i[Symbol.iterator] = function () { return this; }, i;
        function verb(n, f) { i[n] = o[n] ? function (v) { return (p = !p) ? { value: __await(o[n](v)), done: n === "return" } : f ? f(v) : v; } : f; }
    }
    function __asyncValues(o) {
        if (!Symbol.asyncIterator)
            throw new TypeError("Symbol.asyncIterator is not defined.");
        var m = o[Symbol.asyncIterator], i;
        return m ? m.call(o) : (o = typeof __values === "function" ? __values(o) : o[Symbol.iterator](), i = {}, verb("next"), verb("throw"), verb("return"), i[Symbol.asyncIterator] = function () { return this; }, i);
        function verb(n) { i[n] = o[n] && function (v) { return new Promise(function (resolve, reject) { v = o[n](v), settle(resolve, reject, v.done, v.value); }); }; }
        function settle(resolve, reject, d, v) { Promise.resolve(v).then(function (v) { resolve({ value: v, done: d }); }, reject); }
    }
    function __makeTemplateObject(cooked, raw) {
        if (Object.defineProperty) {
            Object.defineProperty(cooked, "raw", { value: raw });
        }
        else {
            cooked.raw = raw;
        }
        return cooked;
    }
    ;
    var __setModuleDefault = Object.create ? (function (o, v) {
        Object.defineProperty(o, "default", { enumerable: true, value: v });
    }) : function (o, v) {
        o["default"] = v;
    };
    function __importStar(mod) {
        if (mod && mod.__esModule)
            return mod;
        var result = {};
        if (mod != null)
            for (var k in mod)
                if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k))
                    __createBinding(result, mod, k);
        __setModuleDefault(result, mod);
        return result;
    }
    function __importDefault(mod) {
        return (mod && mod.__esModule) ? mod : { default: mod };
    }
    function __classPrivateFieldGet(receiver, state, kind, f) {
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a getter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot read private member from an object whose class did not declare it");
        return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
    }
    function __classPrivateFieldSet(receiver, state, value, kind, f) {
        if (kind === "m")
            throw new TypeError("Private method is not writable");
        if (kind === "a" && !f)
            throw new TypeError("Private accessor was defined without a setter");
        if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver))
            throw new TypeError("Cannot write private member to an object whose class did not declare it");
        return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
    }

    /**
     * Call this function in your `AppComponent`'s `ngOnInit()`.
     */
    function handlePreview(client, repoName, linkResolver, defaultURL, enabled) {
        if (linkResolver === void 0) { linkResolver = function (doc) { return "/" + doc.uid; }; }
        if (defaultURL === void 0) { defaultURL = '/'; }
        if (enabled === void 0) { enabled = true; }
        var _a, _b;
        return __awaiter(this, void 0, void 0, function () {
            var toolbarScript, body, isManualRef;
            return __generator(this, function (_c) {
                if (!enabled) {
                    return [2 /*return*/];
                }
                toolbarScript = document.createElement('script');
                toolbarScript.setAttribute('async', 'async');
                toolbarScript.setAttribute('defer', 'defer');
                toolbarScript.setAttribute('src', "https://static.cdn.prismic.io/prismic.js?new=true&repo=" + repoName);
                body = document.getElementsByTagName('body').item(0);
                body === null || body === void 0 ? void 0 : body.appendChild(toolbarScript);
                isManualRef = (((_b = (_a = client) === null || _a === void 0 ? void 0 : _a.refState) === null || _b === void 0 ? void 0 : _b.mode) || '').toLowerCase() === 'manual';
                if (isManualRef) {
                    client.resolvePreviewURL({
                        defaultURL: defaultURL,
                        linkResolver: linkResolver
                    }).then(function (url) {
                        if (location.pathname !== url && url !== defaultURL) {
                            location.replace(url);
                        }
                    });
                }
                return [2 /*return*/];
            });
        });
    }

    var _a;
    /**
     * Use this as the `ref` when constructing your client.
     */
    var prismicPreviewRef = (_a = document.cookie
        .split('; ')
        .find(function (row) { return row.startsWith("" + client.cookie.preview); })) === null || _a === void 0 ? void 0 : _a.split('=')[1];

    /**
     * Generated bundle index. Do not edit.
     */

    exports.LINK_RESOLVER = LINK_RESOLVER;
    exports.LINK_RESOLVER_DEFAULT_ROUTE = LINK_RESOLVER_DEFAULT_ROUTE;
    exports.LINK_RESOLVER_URL = LINK_RESOLVER_URL;
    exports.PreviewGuard = PreviewGuard;
    exports.PrismicClientModule = PrismicClientModule;
    exports.REPOSITORY_NAME = REPOSITORY_NAME;
    exports.RenderHtmlPipe = RenderHtmlPipe;
    exports.RenderImagePipe = RenderImagePipe;
    exports.SafePipe = SafePipe;
    exports.handlePreview = handlePreview;
    exports.prismicPreviewRef = prismicPreviewRef;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ngx-prismic-client.umd.js.map
