import { Inject, Injectable, InjectionToken, Optional } from '@angular/core';
import { Router } from '@angular/router';
import { createClient, getEndpoint } from '@prismicio/client';
import { from } from 'rxjs';
import { map } from 'rxjs/operators';
import * as i0 from "@angular/core";
import * as i1 from "@angular/router";
/**
 * Name of your prismic repository.
 */
export const REPOSITORY_NAME = new InjectionToken('REPOSITORY_NAME');
/**
 * Injection token to provide a link resolver function.
 *
 * This could be done based on doc type and uid.
 */
export const LINK_RESOLVER = new InjectionToken('LINK_RESOLVER');
/**
 * Injection token to provide a custom fallback route for link resolving.
 * Default is `/`.
 */
export const LINK_RESOLVER_DEFAULT_ROUTE = new InjectionToken('LINK_RESOLVER_DEFAULT_ROUTE');
/**
 * Injection token to provide the URL for the link resolver.
 *
 * This value must match the setting in your Prismic Repo.
 */
export const LINK_RESOLVER_URL = new InjectionToken('LINK_RESOLVER_URL');
/**
 * A Guard to easily enable redirects for Prismic Previews.
 * You must provide `LINK_RESOLVER` and `LINK_RESOLVER_URL`.
 *
 * When a preview-token is present, this guard automatically
 * redirects based on the provided `LINK_RESOLVER`.
 *
 * If no token is present, the guard does nothing.
 *
 * Compiler-Flags:
 * - @dynamic (Allow lambda functions)
 */
export class PreviewGuard {
    constructor(router, repoName, linkResolver, linkResolverUrl, defaultRoute = '/') {
        this.router = router;
        this.repoName = repoName;
        this.linkResolver = linkResolver;
        this.linkResolverUrl = linkResolverUrl;
        this.defaultRoute = defaultRoute;
        /**
         * Prismic supplies the preview token in a query param named `token`.
         */
        this.QUERY_PARAM_KEY = 'token';
        const endpoint = getEndpoint(this.repoName);
        this.client = createClient(endpoint);
    }
    canActivateChild(next, state) {
        if (state.url.startsWith(this.linkResolverUrl)) {
            const params = next.queryParamMap;
            if (!params.has(this.QUERY_PARAM_KEY)) {
                return this.router.parseUrl(this.defaultRoute);
            }
            const previewToken = params.get(this.QUERY_PARAM_KEY);
            const resolvedUrl = from(this.client.resolvePreviewURL({
                previewToken,
                linkResolver: this.linkResolver,
                defaultURL: this.defaultRoute
            }));
            return resolvedUrl.pipe(map(url => this.router.parseUrl(url)));
        }
        return true;
    }
}
PreviewGuard.ɵprov = i0.ɵɵdefineInjectable({ factory: function PreviewGuard_Factory() { return new PreviewGuard(i0.ɵɵinject(i1.Router), i0.ɵɵinject(REPOSITORY_NAME), i0.ɵɵinject(LINK_RESOLVER), i0.ɵɵinject(LINK_RESOLVER_URL), i0.ɵɵinject(LINK_RESOLVER_DEFAULT_ROUTE, 8)); }, token: PreviewGuard, providedIn: "root" });
PreviewGuard.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
PreviewGuard.ctorParameters = () => [
    { type: Router },
    { type: String, decorators: [{ type: Inject, args: [REPOSITORY_NAME,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [LINK_RESOLVER,] }] },
    { type: String, decorators: [{ type: Inject, args: [LINK_RESOLVER_URL,] }] },
    { type: undefined, decorators: [{ type: Inject, args: [LINK_RESOLVER_DEFAULT_ROUTE,] }, { type: Optional }] }
];
//# sourceMappingURL=preview.guard.js.map