import { Pipe } from '@angular/core';
import { asHTML } from '@prismicio/helpers';
/**
 * This pipe is used to render an array of Prismic Paragraphs
 * to HTML.
 *
 * @example
 * <!-- text is an array of paragraphs -->
 * <ng-container [innerHTML]="doc.data.text | renderHtml"></ng-container>
 */
export class RenderHtmlPipe {
    /**
     * Takes Paragraphs and renders them to HTML.
     * It is possible to use a custom serializer function to change rendering
     * of certain elements, for example to add classes to standard tags.
     *
     * @param value paragraph definition to render
     * @param htmlSerializer optional HtmlResolver which modifies the rendering of certain elements
     */
    transform(value, htmlSerializer) {
        if (!(Array.isArray(value) && value.length > 0)) {
            return '';
        }
        return asHTML(value, undefined, htmlSerializer);
    }
}
RenderHtmlPipe.decorators = [
    { type: Pipe, args: [{
                name: 'renderHtml'
            },] }
];
//# sourceMappingURL=render-html.pipe.js.map