import { InjectionToken } from '@angular/core';
import { ActivatedRouteSnapshot, CanActivateChild, Router, RouterStateSnapshot, UrlTree } from '@angular/router';
import { LinkResolverFunction } from '@prismicio/helpers';
import { Observable } from 'rxjs';
/**
 * Name of your prismic repository.
 */
export declare const REPOSITORY_NAME: InjectionToken<string>;
/**
 * Injection token to provide a link resolver function.
 *
 * This could be done based on doc type and uid.
 */
export declare const LINK_RESOLVER: InjectionToken<LinkResolverFunction<string>>;
/**
 * Injection token to provide a custom fallback route for link resolving.
 * Default is `/`.
 */
export declare const LINK_RESOLVER_DEFAULT_ROUTE: InjectionToken<string>;
/**
 * Injection token to provide the URL for the link resolver.
 *
 * This value must match the setting in your Prismic Repo.
 */
export declare const LINK_RESOLVER_URL: InjectionToken<string>;
/**
 * A Guard to easily enable redirects for Prismic Previews.
 * You must provide `LINK_RESOLVER` and `LINK_RESOLVER_URL`.
 *
 * When a preview-token is present, this guard automatically
 * redirects based on the provided `LINK_RESOLVER`.
 *
 * If no token is present, the guard does nothing.
 *
 * Compiler-Flags:
 * - @dynamic (Allow lambda functions)
 */
export declare class PreviewGuard implements CanActivateChild {
    private readonly router;
    private readonly repoName;
    private readonly linkResolver;
    private readonly linkResolverUrl;
    private readonly defaultRoute;
    /**
     * Prismic supplies the preview token in a query param named `token`.
     */
    private readonly QUERY_PARAM_KEY;
    private readonly client;
    constructor(router: Router, repoName: string, linkResolver: LinkResolverFunction, linkResolverUrl: string, defaultRoute?: string);
    canActivateChild(next: ActivatedRouteSnapshot, state: RouterStateSnapshot): boolean | UrlTree | Observable<UrlTree>;
}
